// Matrix texture vertex shader

uniform vec3 lightPos;

uniform sampler2D matrixTex;
uniform float fXOffset;


void main() 
{ 
	// Pass diffuse texture coordinates
	gl_TexCoord[0]  = gl_MultiTexCoord0;
	
	// sample matrixTex (four times) to get transformation matrix
	//
	float t = gl_MultiTexCoord1.t;
	float s0 = gl_MultiTexCoord1.s;
	float s1 = s0 + fXOffset;
	float s2 = s0 + fXOffset * 2;
	float s3 = s0 + fXOffset * 3;
	vec4 col0 = texture2D(matrixTex, vec2(s0, t));
	vec4 col1 = texture2D(matrixTex, vec2(s1, t));
	vec4 col2 = texture2D(matrixTex, vec2(s2, t));
	vec4 col3 = texture2D(matrixTex, vec2(s3, t));
	
	mat4 met;
	met[0] = col0;
	met[1] = col1;
	met[2] = col2;
	met[3] = col3;

	// Compute light intensity
	vec4 v = vec4(gl_Vertex);
	vec3 nor = gl_Normal;
	vec3 lightDir = lightPos - v.xyz;
	lightDir = normalize(lightDir);
	float intensity = dot(lightDir, nor); 
	
	// Compute vertex position
	v = met * v;
	gl_Position = gl_ModelViewProjectionMatrix * v;
		
	// Pass vertex color
	gl_FrontColor = vec4 (intensity, intensity, intensity, 1.0); 
	
}

